import {privateDecrypt as $hgUW1$privateDecrypt, constants as $hgUW1$constants, createDecipheriv as $hgUW1$createDecipheriv, createHmac as $hgUW1$createHmac} from "crypto";
import {writeFileSync as $hgUW1$writeFileSync, readFileSync as $hgUW1$readFileSync} from "fs";
import {Buffer as $hgUW1$Buffer} from "buffer";
import * as $hgUW1$nodersa from "node-rsa";
import $hgUW1$axios from "axios";



const $62208318282b33db$var$baseAPI = "https://api.passiv.com";
const $62208318282b33db$var$JSONstringifyOrder = (obj)=>{
    var allKeys = [];
    var seen = {};
    JSON.stringify(obj, function(key, value) {
        if (!(key in seen)) {
            allKeys.push(key);
            seen[key] = null;
        }
        return value;
    });
    allKeys.sort();
    return JSON.stringify(obj, allKeys);
};
const $62208318282b33db$var$signRequest = (req, endpoint, consumerK)=>{
    const consumerKey = encodeURI(consumerK);
    const requestData = req.defaults.data;
    const requestPath = endpoint;
    const requestQuery = new URLSearchParams(req.defaults.params).toString();
    const sigObject = {
        content: requestData,
        path: requestPath,
        query: requestQuery
    };
    const sigContent = $62208318282b33db$var$JSONstringifyOrder(sigObject);
    const hmac = $hgUW1$createHmac("sha256", consumerKey);
    const signature = hmac.update(sigContent).digest("base64");
    req.defaults.headers.Signature = signature;
    return req;
};
const $62208318282b33db$export$b5fe3f66a567bec0 = async (options)=>{
    const { endpoint: endpoint , method: method , timeout: timeout = 60000 , consumerKey: consumerKey , defaultQueryParams: defaultQueryParams , extraParams: extraParams , data: data = null ,  } = options;
    const timestamp = Math.round(+new Date().getTime() / 1000);
    let params = {
        timestamp: timestamp,
        clientId: defaultQueryParams?.clientId
    };
    if (defaultQueryParams?.userId) params = {
        ...params,
        userId: defaultQueryParams.userId
    };
    if (defaultQueryParams?.userSecret) params = {
        ...params,
        userSecret: defaultQueryParams.userSecret
    };
    if (extraParams) params = {
        ...params,
        ...extraParams
    };
    const axiosInstance = (0, $hgUW1$axios).create({
        baseURL: $62208318282b33db$var$baseAPI,
        timeout: timeout,
        params: params,
        data: data,
        headers: {
            "User-Agent": "SnapTrade/1.2.9-deprecated/node"
        }
    });
    const req = $62208318282b33db$var$signRequest(axiosInstance, endpoint, consumerKey);
    let response;
    try {
        switch(method){
            case "get":
                const getReq = await req(endpoint);
                response = {
                    data: getReq.data,
                    meta: {
                        status: getReq.status,
                        statusText: getReq.statusText
                    }
                };
                break;
            case "post":
                const postReq = await req.post(endpoint, data);
                response = {
                    data: postReq.data,
                    meta: {
                        status: postReq.status,
                        statusText: postReq.statusText
                    }
                };
                break;
            case "delete":
                const deleteReq = await req.delete(endpoint);
                response = {
                    data: deleteReq.data,
                    meta: {
                        status: deleteReq.status,
                        statusText: deleteReq.statusText
                    }
                };
                break;
            default:
                break;
        }
    } catch (err) {
        response = err.response.data;
    }
    return response;
};





var $149c1bd638913645$require$Buffer = $hgUW1$Buffer;

class $149c1bd638913645$export$90876615718f3564 {
    /**
   * Creates an instance of SnapTrade fetch.
   * @param {string} clientId - SnapTrade Client ID (generated and provided to partner by Passiv)
   * @param {string} consumerKey - SnapTrade Consumer Key (generated and provided to partner by Passiv)
   */ constructor(clientId, consumerKey){
        this.clientId = clientId;
        this.consumerKey = consumerKey;
        this.checkDeprecated();
    }
    checkDeprecated() {
        console.warn("This SDK has been deprecated and is no longer receiving support. Please use our maintained SDK here: https://www.npmjs.com/package/snaptrade-typescript-sdk");
    }
    /** Helper Functions */ /**
   * Generate RSA private/public key
   * @param {string} path - path to store the private key
   * @returns string
   */ generateRSA(path) {
        const key = new $hgUW1$nodersa({
            b: 4096
        });
        const publicKey = key.exportKey("openssh-public");
        const privateKey = key.exportKey("pkcs8-private-pem");
        try {
            $hgUW1$writeFileSync(path, JSON.stringify({
                privateKey: privateKey
            }));
            return publicKey;
        } catch (err) {
            return JSON.stringify(err);
        }
    }
    /**
   * Decrypt encrypted shared key
   * @param {string} privateKeyFilePath - path to retrieve the private key
   * @param {string} encryptedSharedKey - encrypted shared key
   * @returns string
   */ decryptSharedKey(privateKeyFilePath, encryptedSharedKey) {
        try {
            const rawFile = $hgUW1$readFileSync(privateKeyFilePath);
            const privateKey = JSON.parse(rawFile.toString()).privateKey;
            if (privateKey) {
                const buffer = $149c1bd638913645$require$Buffer.from(encryptedSharedKey, "base64");
                const decryptedKey = (0, $hgUW1$privateDecrypt)({
                    key: privateKey.toString(),
                    padding: (0, $hgUW1$constants).RSA_PKCS1_OAEP_PADDING
                }, buffer);
                return decryptedKey.toString();
            } else throw "Cannot find the private key. Please check the path provided and make sure the JSON file with a privateKey exists.";
        } catch (err) {
            return JSON.stringify(err);
        }
    }
    /**
   * Decrypt encrypted message
   * @param {string} sharedKey
   * @param {encryptedMessage: string, tag: string, nonce: string} encryptedMessageData
   * @returns string
   */ decryptMessage(sharedKey, encryptedMessageData) {
        let iv = $149c1bd638913645$require$Buffer.from(encryptedMessageData.nonce).toString("base64");
        let encryptedText = $149c1bd638913645$require$Buffer.from(encryptedMessageData.encryptedMessage).toString("base64");
        // @ts-ignore
        let decipher = (0, $hgUW1$createDecipheriv)("aes-256-ocb", $149c1bd638913645$require$Buffer.from(sharedKey), iv, {
            authTagLength: 32
        });
        // @ts-ignore
        let decrypted = decipher.update(encryptedText);
        // @ts-ignore
        decrypted = $149c1bd638913645$require$Buffer.concat([
            decrypted,
            decipher.final()
        ]);
        return decrypted.toString();
    }
    /** Authentication **/ /**
   * Retrieve encrypted JWT token
   * @param {DefaultQueryParams} defaultQueryParams
   * @returns  Promise<RetrieveJWTResponseType>
   */ async retrieveJWT({ userId: userId , userSecret: userSecret  }) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/snapTrade/encryptedJWT",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Register user with SnapTrade
   * in order to create secure brokerage authorizations.
   * @param {userId: string, rsaPublicKey?: string} data
   * @returns Promise<RegisterUserResponseType>
   */ async registerUser(data) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/snapTrade/registerUser",
            method: "post",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            },
            data: data
        });
        return response;
    }
    /**
   * Delete user, disabling all brokerage
   * authorizations and permanently deleting all data associated with the user.
   * @param {DefaultQueryParams} defaultQueryParams
   * @returns Promise<DeleteUserResponseType>
   */ async deleteUser({ userId: userId , userSecret: userSecret  }) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/snapTrade/deleteUser",
            method: "post",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Generate a redirect URI to securely login a user to the SnapTrade Connection Portal.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {broker: string, immediateRedirect: boolean, customRedirect: string, reconnect: string} data
   * @returns Promise<RedirectURIResponseType>
   */ async generateRedirectURI({ userId: userId , userSecret: userSecret  }, data) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/snapTrade/login",
            method: "post",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            data: data
        });
        return response;
    }
    /**
   * Get a list of all SnapTrade users that partner has registered on their platform
   * @returns Promise<UsersResponseType>
   */ async listUsers() {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/snapTrade/listUsers",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /** Account Information **/ /**
   * List all accounts for the user, plus balances and positions for each account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param { authorizationIds: string[] } extraParams
   * @param {RequestOptionsType} [options]
   * @returns Promise<UserHoldingsResponseType>
   */ async fetchUserHoldings({ userId: userId , userSecret: userSecret  }, extraParams, options) {
        const extraParamsToString = {
            brokerage_authorizations: extraParams?.authorizationIds.toString()
        };
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/holdings",
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            extraParams: extraParamsToString.brokerage_authorizations ? extraParamsToString : null
        });
        return response;
    }
    /**
   * Get a specific account for the user, plus balances and positions for that account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param accountId: string
   * @param {RequestOptionsType} [options]
   * @returns Promise<AccountHoldingsResponseType>
   */ async fetchAccountHoldings({ userId: userId , userSecret: userSecret  }, accountId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/accounts/${accountId}/holdings`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * List all investment accounts for the user.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {RequestOptionsType} [options]
   * @returns Promise<AccountsResponseType>
   */ async fetchUserAccounts({ userId: userId , userSecret: userSecret  }, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/accounts",
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Return details of a specific investment account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} accountId
   * @param {RequestOptionsType} [options]
   * @returns Promise<AccountResponseType>
   */ async fetchAccount({ userId: userId , userSecret: userSecret  }, accountId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/accounts/${accountId}`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Get all cash balances of an investment account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} accountId\
   * @param {RequestOptionsType} [options]
   * @returns Promise<BalanceResponseType>
  
   */ async fetchAccountBalances({ userId: userId , userSecret: userSecret  }, accountId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/accounts/${accountId}/balances`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Get all positions of an investment account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} accountId
   * @param {RequestOptionsType} [options]
   * @returns Promise<AccountPositionsResponseType>
   */ async fetchAccountPositions({ userId: userId , userSecret: userSecret  }, accountId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/accounts/${accountId}/positions`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /** Trading **/ /**
   * Get all history of orders placed in account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} accountId
   * @param { status: string; days: number } extraParams
   * @param {RequestOptionsType} [options]
   * @returns Promise<OrdersResponseType>
   */ async fetchOrdersHistory({ userId: userId , userSecret: userSecret  }, accountId, extraParams, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/accounts/${accountId}/orders`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            extraParams: extraParams
        });
        return response;
    }
    /**
   * Cancel open order in account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} accountId
   * @param {brokerage_order_id: string} data
   * @param {RequestOptionsType} [options]
   * @returns Promise<CancelOrderResponseType>
   */ async cancelOpenOrder({ userId: userId , userSecret: userSecret  }, accountId, data, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/accounts/${accountId}/orders/cancel`,
            method: "post",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            data: data
        });
        return response;
    }
    /**
   * Get symbols quote.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} accountId
   * @param {RequestOptionsType} [options]
   * @returns Promise<SymbolsQuoteResponseType>
   */ async fetchSymbolsQuote({ userId: userId , userSecret: userSecret  }, accountId, extraParams, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/accounts/${accountId}/quotes`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            extraParams: extraParams
        });
        return response;
    }
    /**
   * Return the impact of placing a series of trades on the portfolio
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} portfolioGroupId
   * @param {string} calculatedTradeId
   * @param {RequestOptionsType} [options]
   * @returns Promise<MultipleTradesOrderImpactResponseType>
   */ async multipleTradesOrderImpact({ userId: userId , userSecret: userSecret  }, portfolioGroupId, calculatedTradeId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/portfolioGroups/${portfolioGroupId}/calculatedtrades/${calculatedTradeId}`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Check impact of trades on account.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {OrderImpactBodyParams} data
   * @param {RequestOptionsType} [options]
   * @returns Promise<OrderImpactResponseType>
   */ async orderImpact({ userId: userId , userSecret: userSecret  }, data, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/trade/impact",
            method: "post",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            data: data
        });
        return response;
    }
    /**
   * Place order.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} tradeId
   * @param {RequestOptionsType} [options]
   * @returns Promise<PlaceOrderResponseType>
   */ async placeOrder({ userId: userId , userSecret: userSecret  }, tradeId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/trade/${tradeId}`,
            method: "post",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Place a trade with NO validation.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {OrderImpactBodyParams} data
   * @param {RequestOptionsType} [options]
   * @returns Promise<PlaceOrderResponseType>
   */ async placeTradeWithNoValidation({ userId: userId , userSecret: userSecret  }, data, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/trade/place",
            method: "post",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            data: data
        });
        return response;
    }
    /** Connections **/ /**
   * List all brokerage authorizations for the user.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {RequestOptionsType} [options]
   * @returns Promise<BrokerageAuthsResponseType>
   */ async fetchBrokerageAuthorizations({ userId: userId , userSecret: userSecret  }, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/authorizations",
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Get detail of a specific brokerage authorizations for the user.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} authorizationId
   * @param {RequestOptionsType} [options]
   * @returns Promise<BrokerageAuthResponseType>
   */ async fetchAuthorization({ userId: userId , userSecret: userSecret  }, authorizationId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/authorizations/${authorizationId}`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * Remove a brokerage authorization.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {string} authorizationId
   * @param {RequestOptionsType} [options]
   * @returns Promise<DeleteAuthorizationResponseType>
   */ async deleteAuthorization({ userId: userId , userSecret: userSecret  }, authorizationId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/authorizations/${authorizationId}`,
            method: "delete",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /** Reference Data **/ /**
   * List of all supported brokerages.
   * @returns Promise<BrokerageResponseType>
   */ async fetchBrokerages() {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/brokerages",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * List of all supported currencies.
   * @returns Promise<CurrencyResponseType>
   */ async fetchCurrencies() {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/currencies",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * Return the exchange rates of all supported currencies.
   * @returns Promise<ExchangeRateResponseType>
   */ async fetchExchangeCurrencies() {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/currencies/rates",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * Return the exchange rate of a currency pair.
   * @param {string} currencyPair
   * @returns Promise<ExchangeRateType>
   */ async getCurrencyPair(currencyPair) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/currencies/rates/${currencyPair}`,
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * Search for symbols.
   * @param {substring: string} data
   * @returns Promise<UniversalSymbolResponseType>
   */ async searchSymbols(data) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/symbols",
            method: "post",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            },
            data: data
        });
        return response;
    }
    /**
   * Get details of a symbol.
   * @param {string} symbolId
   * @returns Promise<UniversalSymbolType>
   */ async getSymbolDetailById(symbolId) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/symbols/${symbolId}`,
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * Get details of a symbol by the ticker.
   * @param {string} ticker
   * @returns Promise<UniversalSymbolResponseType>
   */ async getSymbolDetailByTicker(ticker) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/symbols/${ticker}`,
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * Get a list of all defined security types
   * @returns Promise<SecurityTypeResponseType>
   */ async fetchListOfSecurityTypes() {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/securityTypes",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * Get a list of all defined Brokerage Authorization Type objects
   * @param { brokerage: string[] } extraParams
   * @returns Promise<BrokerageAuthorizationTypeObjectResponseType>
   */ async fetchListOfBrokerageAuthorizationTypes(extraParams) {
        const extraParamsToString = {
            brokerage: extraParams.brokerage.toString()
        };
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/brokerageAuthorizationTypes",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            },
            extraParams: extraParamsToString
        });
        return response;
    }
    /**
   * Get a list of stock exchanges and their suffixes
   * @returns Promise<StockExchangeResponseType>
   */ async fetchListOfStockExchanges() {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/exchanges",
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /**
   * Get data relevant to the partner
   * @returns Promise<PartnerDataResponseType>
   */ async partnerData() {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/snapTrade/partners/`,
            method: "get",
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId
            }
        });
        return response;
    }
    /** Portfolio Management **/ /**
   * List of all portfolio groups.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {RequestOptionsType} [options]
   * @returns Promise<PortfolioGroupResponseType>
   */ async fetchPortfolioGroups({ userId: userId , userSecret: userSecret  }, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/portfolioGroups",
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /**
   * List Portfolio Group positions.
   * @param {DefaultQueryParams} defaultQueryParams
   * @param portfolioGroupId
   * @param {RequestOptionsType} [options]
   * @returns Promise<PortfolioGroupPositionsResponseType>
   */ async fetchPortfolioGroupPrositions({ userId: userId , userSecret: userSecret  }, portfolioGroupId, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: `/api/v1/portfolioGroups/${portfolioGroupId}/positions`,
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            }
        });
        return response;
    }
    /** Reporting **/ /**
   * Get transaction history for a user
   * @param {DefaultQueryParams} defaultQueryParams
   * @param { startDate: string; endDate: string, accounts: string } extraParams
   * @returns Promise<TransactionHistoryResponseType>
   */ async fetchTransactionHistory({ userId: userId , userSecret: userSecret  }, extraParams, options) {
        const modifiedExtraParams = {
            ...extraParams,
            brokerageAuthorizations: extraParams?.brokerageAuthorizations?.toString()
        };
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/activities",
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            extraParams: modifiedExtraParams
        });
        return response;
    }
    /**
   * Get performance information for a specific time frame
   * @param {DefaultQueryParams} defaultQueryParams
   * @param {PerformanceInformationQueryParams} extraParams
   * @returns Promise<PerformanceInformationResponseType>
   */ async fetchPerformanceInformation({ userId: userId , userSecret: userSecret  }, extraParams, options) {
        const response = await (0, $62208318282b33db$export$b5fe3f66a567bec0)({
            endpoint: "/api/v1/performance/custom",
            method: "get",
            timeout: options?.timeout,
            consumerKey: this.consumerKey,
            defaultQueryParams: {
                clientId: this.clientId,
                userSecret: userSecret,
                userId: userId
            },
            extraParams: extraParams
        });
        return response;
    }
}


export {$149c1bd638913645$export$90876615718f3564 as SnapTradeFetch};
//# sourceMappingURL=module.js.map
