"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.request = void 0;
const axios_1 = require("axios");
const crypto = require("crypto");
const baseAPI = 'https://api.passiv.com';
const JSONstringifyOrder = (obj) => {
    var allKeys = [];
    var seen = {};
    JSON.stringify(obj, function (key, value) {
        if (!(key in seen)) {
            allKeys.push(key);
            seen[key] = null;
        }
        return value;
    });
    allKeys.sort();
    return JSON.stringify(obj, allKeys);
};
const signRequest = (req, endpoint, consumerK) => {
    const consumerKey = encodeURI(consumerK);
    const requestData = req.defaults.data;
    const requestPath = endpoint;
    const requestQuery = new URLSearchParams(req.defaults.params).toString();
    const sigObject = {
        content: requestData,
        path: requestPath,
        query: requestQuery,
    };
    const sigContent = JSONstringifyOrder(sigObject);
    const hmac = crypto.createHmac('sha256', consumerKey);
    const signature = hmac.update(sigContent).digest('base64');
    req.defaults.headers.Signature = signature;
    return req;
};
const request = async (options) => {
    const { endpoint, method, timeout = 60000, consumerKey, defaultQueryParams, extraParams, data = null, } = options;
    const timestamp = Math.round(+new Date().getTime() / 1000);
    let params = {
        timestamp: timestamp,
        clientId: defaultQueryParams?.clientId,
    };
    if (defaultQueryParams?.userId) {
        params = { ...params, userId: defaultQueryParams.userId };
    }
    if (defaultQueryParams?.userSecret) {
        params = { ...params, userSecret: defaultQueryParams.userSecret };
    }
    if (extraParams) {
        params = { ...params, ...extraParams };
    }
    const axiosInstance = axios_1.default.create({
        baseURL: baseAPI,
        timeout,
        params: params,
        data: data,
        headers: {
            'User-Agent': 'SnapTrade/1.2.9-deprecated/node',
        },
    });
    const req = signRequest(axiosInstance, endpoint, consumerKey);
    let response;
    try {
        switch (method) {
            case 'get':
                const getReq = await req(endpoint);
                response = {
                    data: getReq.data,
                    meta: {
                        status: getReq.status,
                        statusText: getReq.statusText,
                    },
                };
                break;
            case 'post':
                const postReq = await req.post(endpoint, data);
                response = {
                    data: postReq.data,
                    meta: {
                        status: postReq.status,
                        statusText: postReq.statusText,
                    },
                };
                break;
            case 'delete':
                const deleteReq = await req.delete(endpoint);
                response = {
                    data: deleteReq.data,
                    meta: {
                        status: deleteReq.status,
                        statusText: deleteReq.statusText,
                    },
                };
                break;
            default:
                break;
        }
    }
    catch (err) {
        response = err.response.data;
    }
    return response;
};
exports.request = request;
