interface RequestOptionsType {
    timeout?: number;
}
interface CurrencyType {
    id: string;
    code: string;
    name: string;
}
interface BrokerageAuthorizationType {
    id: string;
    created_date: string;
    updated_date: string;
    name: string;
    type: string;
    disabled: boolean;
    disabled_date: string | null;
    meta: {
        identifier: string;
    };
    brokerage: {
        id: string;
        name: string;
        display_name: string;
        description: string;
        aws_s3_logo_url: string;
        aws_s3_square_logo_url: string;
        slug: string;
        url: string;
        enabled: boolean;
        maintenance_mode: boolean;
        allows_fractional_units: boolean;
        allows_trading: boolean;
        has_reporting: boolean;
        is_real_time_connection: boolean;
        allows_trading_through_snaptrade_api: boolean;
        is_scraping_integration: boolean;
        transaction_available_in_realtime: boolean;
        has_timestamped_transactions: boolean;
        are_fees_shown_in_transactions: boolean;
        open_url: string;
        credentials_stored_in_vault: boolean;
        has_option_position_support: boolean;
        has_option_trading_support: boolean;
        allows_cryptocurrency_symbols: boolean;
        allows_cryptocurrency_and_regular_securities: boolean;
        handles_stock_splits: boolean;
        default_currency: string;
        brokerage_type: string;
        exchanges: string[];
    };
}
interface AccountType {
    brokerage_authorization: BrokerageAuthorizationType;
    id: string;
    number: string;
    name: string;
}
interface _AccountType {
    id: string;
    brokerage_authorization: string;
    portfolio_group: string;
    name: string;
    number: string;
    institution_name: string;
    meta: {
        type: string;
        status: string;
        institution_name: string;
        is_billing: boolean;
        is_primary: boolean;
        client_account_type: string;
    };
    cash_restrictions: [];
    created_date: string;
}
interface BalanceType {
    cash: number;
    currency: CurrencyType;
    buying_power: string;
}
interface SymbolType {
    symbol: string;
    name: string;
    description: string;
    currency: CurrencyType;
    exchange: {
        code: string;
        name: string;
    };
}
interface PositionType {
    symbol: {
        symbol: {
            id: string;
            symbol: string;
            description: string;
            currency: DividendsSymbolCurrency;
            exchange: DividendsSymbolExchange;
            currencies: DividendsSymbolCurrency[];
            type: {
                id: string;
                code: string;
                is_supported: boolean;
                description: string;
            };
            raw_symbol: string;
        };
        id: string;
        description: string;
        local_id: string;
        security_type: {};
        listing_exchange: {};
        is_quotable: boolean;
        is_tradable: boolean;
    };
    price: number;
    open_pnl: null | number;
    fractional_units: number;
    currency: null | string;
    units: number;
    average_purchase_price: number;
}
interface UniversalSymbolType {
    id: string;
    symbol: string;
    description: string;
    currency: {
        id: string;
        code: string;
        name: string;
        include_in_rate_data: boolean;
    };
    exchange: DividendsSymbolExchange;
    currencies: [];
    type: {
        id: string;
        code: string;
        is_supported: boolean;
        description: string;
    };
    raw_symbol: string;
}
interface ManualTradeSymbolType {
    brokerage_symbol_id: string;
    universal_symbol_id: string;
    currency: CurrencyType;
    local_id: string;
    description: string;
    symbol: string;
}
interface TradeImpactType {
    account: string;
    currency: string;
    remaining_cash: number;
    estimated_commissions: number;
    forex_fees: number;
}
interface BrokerageType {
    authorization_types: {
        type: 'read' | 'trade';
        auth_type: string;
    }[];
    maintenance_windows: [];
    brokerage_type: {
        id: string;
        name: string;
    };
    id: string;
    name: string;
    description: string;
    slug: string;
    url: string;
    maintenance_mode: boolean;
    allows_fractional_units: boolean | null;
    allows_trading: boolean;
    has_reporting: boolean;
    is_real_time_connection: boolean;
    aws_s3_logo_url: string;
    aws_s3_square_logo_url: string;
    open_url: string;
    display_name: string;
    enabled: boolean;
    has_option_position_support: boolean;
    has_option_trading_support: boolean;
    allows_cryptocurrency_symbols: boolean;
    allows_cryptocurrency_and_regular_securities: boolean;
    confirm_prompt: string | null;
    default_connection_type: string;
}
interface PortfolioGroupType {
    id: string;
    name: string;
}
interface PortfolioGroupPositionType {
    symbol: SymbolType;
    price: number;
    units: number;
    fractional_units: number;
}
interface OrderType {
    brokerage_order_id: string;
    status: string;
    symbol: string;
    universal_symbol: UniversalSymbolType;
    action: string;
    total_quantity: string;
    open_quantity: string;
    canceled_quantity: string;
    filled_quantity: string;
    execution_price: string;
    limit_price: number | null;
    stop_price: number | null;
    order_type: string;
    time_in_force: 'FOK' | 'Day';
    time_placed: string;
    time_updated: string;
    expiry_date: string | null;
}
interface OptionPosition {
    symbol: {
        id: string;
        description: string;
        option_symbol: string;
        local_id: string;
        security_type: {};
        listing_exchange: {};
        is_quotable: boolean;
        is_tradable: boolean;
    };
    price: number;
    currency: CurrencyType;
}
interface Timeframe {
    date: string;
    value: number;
    currency: string;
}
interface Contribution {
    contributions: number;
    date: string;
    currency: string;
}
interface ReturnRateTimeframe {
    periodStart: string;
    periodEnd: string;
    rateOfReturn: number;
}
interface DividendsSymbolCurrency {
    id: string;
    code: string;
    name: string;
    include_in_rate_data: boolean;
}
interface DividendsSymbolExchange {
    id: string;
    mic_code: string;
    code: string;
    name: string;
    timezone: string;
    start_time: string;
    close_time: string;
    suffix: null;
    allows_cryptocurrency_symbols: boolean;
}
interface DividendsSymbolType {
    id: string;
    code: string;
    is_supported: boolean;
    description: string;
}
interface DividendsSymbol {
    id: string;
    symbol: string;
    description: string;
    currency: DividendsSymbolCurrency;
    exchange: DividendsSymbolExchange;
    currencies: any[];
    type: DividendsSymbolType;
    raw_symbol: string;
}
interface Dividends {
    symbol: DividendsSymbol;
    amount: number;
    currency: string;
}
interface DividendsTimelineInfo {
    symbol: string;
    amount: number;
    currency: string;
}
interface DividendsTimeline {
    date: string;
    dividends: DividendsTimelineInfo[];
}
interface DefaultQueryParams {
    userId: string;
    userSecret: string;
}
interface OrderImpactBodyParams {
    account_id: string;
    action: 'BUY' | 'SELL';
    order_type: 'Limit' | 'Market';
    price: number;
    stop: number;
    time_in_force: 'Day';
    units: number;
    universal_symbol_id: string;
}
interface PerformanceInformationQueryParams {
    startDate: string;
    endDate: string;
    accounts?: string;
    frequency?: 'daily' | 'weekly' | 'monthly' | 'quarterly' | 'yearly';
    detailed?: boolean;
}
interface ResponseType {
    meta: {
        status: number;
        statusText: string;
    };
}
interface RetrieveJWTResponseType extends ResponseType {
    data: {
        sharedKey: string;
        encryptedMessageData: {
            encryptedMessage: string;
            tag: string;
            nonce: string;
        };
    };
}
interface RegisterUserResponseType extends ResponseType {
    data: {
        userId: string;
        userSecret: string;
    };
}
interface DeleteUserResponseType extends ResponseType {
    data: {
        status: string;
        userId: string;
    };
}
interface RedirectURIResponseType extends ResponseType {
    data: {
        redirectURI: string;
    };
}
interface UsersResponseType extends ResponseType {
    data: string[];
}
interface UserHoldingsResponseType extends ResponseType {
    data: {
        account: AccountType;
        balances: BalanceType[];
        positions: PositionType[];
        option_positions: OptionPosition[];
        orders: OrderType[];
        errors: null | string;
        total_value: {
            currency: string;
            value: number;
        };
    }[];
}
interface AccountHoldingsResponseType extends ResponseType {
    data: {
        account: _AccountType;
        positions: PositionType[];
        balances: {
            currency: CurrencyType;
            cash: number;
        }[];
        orders: OrderType[];
        option_positions: OptionPosition[];
        cache_timestamp: string;
        cache_expiry: string;
        cache_expired: boolean;
    };
}
interface AccountResponseType extends ResponseType {
    data: _AccountType;
}
interface AccountsResponseType extends ResponseType {
    data: _AccountType[];
}
interface BalanceResponseType extends ResponseType {
    data: {
        cash: number;
        currency: CurrencyType;
    }[];
}
interface AccountPositionsResponseType extends ResponseType {
    data: PositionType[];
}
interface OrderResponseType extends ResponseType {
    data: OrderType[];
}
interface PlaceOrderResponseType extends ResponseType {
    data: OrderType;
}
interface CancelOrderResponseType extends ResponseType {
    data: OrderType;
}
interface OrderImpactResponseType extends ResponseType {
    data: {
        trade: {
            id: string;
            account: string;
            order_type: string;
            time_in_force: 'FOK' | 'Day';
            symbol: ManualTradeSymbolType;
            action: string;
            units: number;
            price: number;
        };
        trade_impacts: TradeImpactType[];
        combined_remaining_balance: {
            account: {
                id: string;
                number: string;
                name: string;
            };
            currency: CurrencyType;
            cash: number;
            buying_power: number | null;
        };
    };
}
interface MultipleTradesOrderImpactResponseType extends ResponseType {
    data: TradeImpactType[];
}
interface SecurityTypeResponseType extends ResponseType {
    data: {
        id: string;
        code: string;
        description: string;
        is_supported: boolean;
    }[];
}
interface BrokerageResponseType extends ResponseType {
    data: BrokerageType[];
}
interface BrokerageAuthsResponseType extends ResponseType {
    data: BrokerageAuthorizationType[];
}
interface BrokerageAuthResponseType extends ResponseType {
    data: BrokerageAuthorizationType;
}
interface DeleteAuthorizationResponseType extends ResponseType {
    data: '';
}
interface BrokerageAuthorizationTypeObjectResponseType extends ResponseType {
    data: {
        id: string;
        type: 'read' | 'trade';
        auth_type: string;
        brokerage: {
            id: string;
            name: string;
            slug: string;
        };
    };
}
interface TransactionHistoryResponseType extends ResponseType {
    data: {
        id: string;
        symbol: {
            description: string;
            id: string;
            symbol: string;
            raw_symbol: string;
            currency: CurrencyType;
            exchange: {
                code: string;
                mic_code: string;
                name: string;
                suffix: string | null;
            } | null;
        };
        option_symbol: string | null;
        account: {
            id: string;
            number: string;
            name: string;
        };
        currency: CurrencyType;
        type: string;
        description: string;
        amount: number;
        price: number;
        units: number;
        fee: number;
        settlement_date: string;
        trade_date: string;
        institution: string;
        option_type: string;
    }[];
}
interface PerformanceInformationResponseType extends ResponseType {
    data: {
        totalEquityTimeframe: Timeframe[];
        contributions: Contribution;
        contributionTimeframe: Timeframe[];
        contributionTimeframeCumulative: Timeframe[];
        withdrawalTimeframe: Timeframe[];
        contributionStreak: number;
        contributionMonthsContributed: number;
        contributionTotalMonths: number;
        dividendIncome: number;
        monthlyDividends: number;
        dividends: Dividends[];
        badTickers: any[];
        dividendTimeline: DividendsTimeline[];
        commissions: number;
        forexFees: number;
        fees: number;
        feeSavings: number;
        rateOfReturn: number;
        returnRateTimeframe: ReturnRateTimeframe[];
        detailedMode: boolean;
    }[];
}
interface SymbolsQuoteResponseType extends ResponseType {
    data: {
        symbol: UniversalSymbolType;
        bid_price: number;
        ask_price: number;
        last_trade_price: number;
        bid_size: number;
        ask_size: number;
    }[];
}
interface StockExchangeResponseType extends ResponseType {
    data: {
        id: string;
        code: string;
        mic_code: string;
        name: string;
        timezone: string;
        start_time: string;
        close_time: string;
        suffix: string;
    }[];
}
interface PartnerDataResponseType extends ResponseType {
    data: {
        redirect_uri: string;
        can_access_trades: boolean;
        allowed_brokerages: BrokerageType[];
        name: string;
        slug: string;
        logo_url: string;
        pin_required: boolean;
        can_access_holdings: boolean;
        can_access_account_history: boolean;
        can_access_reference_data: boolean;
        can_access_portfolio_management: boolean;
        can_access_orders: boolean;
    };
}
interface CurrencyResponseType extends ResponseType {
    data: CurrencyType[];
}
interface ExchangeRateResponseType extends ResponseType {
    data: {
        src: CurrencyType;
        dst: CurrencyType;
        exchange_rate: number;
    }[];
}
interface UniversalSymbolResponseType extends ResponseType {
    data: UniversalSymbolType[];
}
interface PortfolioGroupResponseType extends ResponseType {
    data: PortfolioGroupType[];
}
interface PortfolioGroupPositionsResponseType extends ResponseType {
    data: PortfolioGroupPositionType[];
}
/**
 * @class SnapTradeFetch
 */
export class SnapTradeFetch {
    clientId: string;
    consumerKey: string;
    /**
     * Creates an instance of SnapTrade fetch.
     * @param {string} clientId - SnapTrade Client ID (generated and provided to partner by Passiv)
     * @param {string} consumerKey - SnapTrade Consumer Key (generated and provided to partner by Passiv)
     */
    constructor(clientId: string, consumerKey: string);
    checkDeprecated(): void;
    /** Helper Functions */
    /**
     * Generate RSA private/public key
     * @param {string} path - path to store the private key
     * @returns string
     */
    generateRSA(path: string): string;
    /**
     * Decrypt encrypted shared key
     * @param {string} privateKeyFilePath - path to retrieve the private key
     * @param {string} encryptedSharedKey - encrypted shared key
     * @returns string
     */
    decryptSharedKey(privateKeyFilePath: string, encryptedSharedKey: string): string;
    /**
     * Decrypt encrypted message
     * @param {string} sharedKey
     * @param {encryptedMessage: string, tag: string, nonce: string} encryptedMessageData
     * @returns string
     */
    decryptMessage(sharedKey: string, encryptedMessageData: {
        encryptedMessage: string;
        tag: string;
        nonce: string;
    }): string;
    /** Authentication **/
    /**
     * Retrieve encrypted JWT token
     * @param {DefaultQueryParams} defaultQueryParams
     * @returns  Promise<RetrieveJWTResponseType>
     */
    retrieveJWT({ userId, userSecret, }: DefaultQueryParams): Promise<RetrieveJWTResponseType>;
    /**
     * Register user with SnapTrade
     * in order to create secure brokerage authorizations.
     * @param {userId: string, rsaPublicKey?: string} data
     * @returns Promise<RegisterUserResponseType>
     */
    registerUser(data: {
        userId: string;
        rsaPublicKey?: string;
    }): Promise<RegisterUserResponseType>;
    /**
     * Delete user, disabling all brokerage
     * authorizations and permanently deleting all data associated with the user.
     * @param {DefaultQueryParams} defaultQueryParams
     * @returns Promise<DeleteUserResponseType>
     */
    deleteUser({ userId, userSecret, }: DefaultQueryParams): Promise<DeleteUserResponseType>;
    /**
     * Generate a redirect URI to securely login a user to the SnapTrade Connection Portal.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {broker: string, immediateRedirect: boolean, customRedirect: string, reconnect: string} data
     * @returns Promise<RedirectURIResponseType>
     */
    generateRedirectURI({ userId, userSecret }: DefaultQueryParams, data?: {
        broker?: string;
        immediateRedirect?: boolean;
        customRedirect?: string;
        reconnect?: string;
        connectionType?: string;
        connectionPortalVersion?: string;
    }): Promise<RedirectURIResponseType>;
    /**
     * Get a list of all SnapTrade users that partner has registered on their platform
     * @returns Promise<UsersResponseType>
     */
    listUsers(): Promise<UsersResponseType>;
    /** Account Information **/
    /**
     * List all accounts for the user, plus balances and positions for each account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param { authorizationIds: string[] } extraParams
     * @param {RequestOptionsType} [options]
     * @returns Promise<UserHoldingsResponseType>
     */
    fetchUserHoldings({ userId, userSecret }: DefaultQueryParams, extraParams?: {
        authorizationIds: string[];
    }, options?: RequestOptionsType): Promise<UserHoldingsResponseType>;
    /**
     * Get a specific account for the user, plus balances and positions for that account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param accountId: string
     * @param {RequestOptionsType} [options]
     * @returns Promise<AccountHoldingsResponseType>
     */
    fetchAccountHoldings({ userId, userSecret }: DefaultQueryParams, accountId: string, options?: RequestOptionsType): Promise<AccountHoldingsResponseType>;
    /**
     * List all investment accounts for the user.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {RequestOptionsType} [options]
     * @returns Promise<AccountsResponseType>
     */
    fetchUserAccounts({ userId, userSecret }: DefaultQueryParams, options?: RequestOptionsType): Promise<AccountsResponseType>;
    /**
     * Return details of a specific investment account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} accountId
     * @param {RequestOptionsType} [options]
     * @returns Promise<AccountResponseType>
     */
    fetchAccount({ userId, userSecret }: DefaultQueryParams, accountId: string, options?: RequestOptionsType): Promise<AccountResponseType>;
    /**
     * Get all cash balances of an investment account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} accountId\
     * @param {RequestOptionsType} [options]
     * @returns Promise<BalanceResponseType>
    
     */
    fetchAccountBalances({ userId, userSecret }: DefaultQueryParams, accountId: string, options?: RequestOptionsType): Promise<BalanceResponseType>;
    /**
     * Get all positions of an investment account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} accountId
     * @param {RequestOptionsType} [options]
     * @returns Promise<AccountPositionsResponseType>
     */
    fetchAccountPositions({ userId, userSecret }: DefaultQueryParams, accountId: string, options?: RequestOptionsType): Promise<AccountPositionsResponseType>;
    /** Trading **/
    /**
     * Get all history of orders placed in account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} accountId
     * @param { status: string; days: number } extraParams
     * @param {RequestOptionsType} [options]
     * @returns Promise<OrdersResponseType>
     */
    fetchOrdersHistory({ userId, userSecret }: DefaultQueryParams, accountId: string, extraParams?: {
        status?: string;
        days?: number;
    }, options?: RequestOptionsType): Promise<OrderResponseType>;
    /**
     * Cancel open order in account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} accountId
     * @param {brokerage_order_id: string} data
     * @param {RequestOptionsType} [options]
     * @returns Promise<CancelOrderResponseType>
     */
    cancelOpenOrder({ userId, userSecret }: DefaultQueryParams, accountId: string, data: {
        brokerage_order_id: string;
    }, options?: RequestOptionsType): Promise<CancelOrderResponseType>;
    /**
     * Get symbols quote.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} accountId
     * @param {RequestOptionsType} [options]
     * @returns Promise<SymbolsQuoteResponseType>
     */
    fetchSymbolsQuote({ userId, userSecret }: DefaultQueryParams, accountId: string, extraParams: {
        symbols: string;
        use_ticker?: boolean;
    }, options?: RequestOptionsType): Promise<SymbolsQuoteResponseType>;
    /**
     * Return the impact of placing a series of trades on the portfolio
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} portfolioGroupId
     * @param {string} calculatedTradeId
     * @param {RequestOptionsType} [options]
     * @returns Promise<MultipleTradesOrderImpactResponseType>
     */
    multipleTradesOrderImpact({ userId, userSecret }: DefaultQueryParams, portfolioGroupId: string, calculatedTradeId: string, options?: RequestOptionsType): Promise<MultipleTradesOrderImpactResponseType>;
    /**
     * Check impact of trades on account.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {OrderImpactBodyParams} data
     * @param {RequestOptionsType} [options]
     * @returns Promise<OrderImpactResponseType>
     */
    orderImpact({ userId, userSecret }: DefaultQueryParams, data: OrderImpactBodyParams, options?: RequestOptionsType): Promise<OrderImpactResponseType>;
    /**
     * Place order.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} tradeId
     * @param {RequestOptionsType} [options]
     * @returns Promise<PlaceOrderResponseType>
     */
    placeOrder({ userId, userSecret }: DefaultQueryParams, tradeId: string, options?: RequestOptionsType): Promise<PlaceOrderResponseType>;
    /**
     * Place a trade with NO validation.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {OrderImpactBodyParams} data
     * @param {RequestOptionsType} [options]
     * @returns Promise<PlaceOrderResponseType>
     */
    placeTradeWithNoValidation({ userId, userSecret }: DefaultQueryParams, data: OrderImpactBodyParams, options?: RequestOptionsType): Promise<PlaceOrderResponseType>;
    /** Connections **/
    /**
     * List all brokerage authorizations for the user.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {RequestOptionsType} [options]
     * @returns Promise<BrokerageAuthsResponseType>
     */
    fetchBrokerageAuthorizations({ userId, userSecret }: DefaultQueryParams, options?: RequestOptionsType): Promise<BrokerageAuthsResponseType>;
    /**
     * Get detail of a specific brokerage authorizations for the user.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} authorizationId
     * @param {RequestOptionsType} [options]
     * @returns Promise<BrokerageAuthResponseType>
     */
    fetchAuthorization({ userId, userSecret }: DefaultQueryParams, authorizationId: string, options?: RequestOptionsType): Promise<BrokerageAuthResponseType>;
    /**
     * Remove a brokerage authorization.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {string} authorizationId
     * @param {RequestOptionsType} [options]
     * @returns Promise<DeleteAuthorizationResponseType>
     */
    deleteAuthorization({ userId, userSecret }: DefaultQueryParams, authorizationId: string, options?: RequestOptionsType): Promise<DeleteAuthorizationResponseType>;
    /** Reference Data **/
    /**
     * List of all supported brokerages.
     * @returns Promise<BrokerageResponseType>
     */
    fetchBrokerages(): Promise<BrokerageResponseType>;
    /**
     * List of all supported currencies.
     * @returns Promise<CurrencyResponseType>
     */
    fetchCurrencies(): Promise<CurrencyResponseType>;
    /**
     * Return the exchange rates of all supported currencies.
     * @returns Promise<ExchangeRateResponseType>
     */
    fetchExchangeCurrencies(): Promise<ExchangeRateResponseType>;
    /**
     * Return the exchange rate of a currency pair.
     * @param {string} currencyPair
     * @returns Promise<ExchangeRateType>
     */
    getCurrencyPair(currencyPair: string): Promise<ExchangeRateResponseType>;
    /**
     * Search for symbols.
     * @param {substring: string} data
     * @returns Promise<UniversalSymbolResponseType>
     */
    searchSymbols(data: {
        substring: string;
    }): Promise<UniversalSymbolResponseType>;
    /**
     * Get details of a symbol.
     * @param {string} symbolId
     * @returns Promise<UniversalSymbolType>
     */
    getSymbolDetailById(symbolId: string): Promise<UniversalSymbolResponseType>;
    /**
     * Get details of a symbol by the ticker.
     * @param {string} ticker
     * @returns Promise<UniversalSymbolResponseType>
     */
    getSymbolDetailByTicker(ticker: string): Promise<UniversalSymbolResponseType>;
    /**
     * Get a list of all defined security types
     * @returns Promise<SecurityTypeResponseType>
     */
    fetchListOfSecurityTypes(): Promise<SecurityTypeResponseType>;
    /**
     * Get a list of all defined Brokerage Authorization Type objects
     * @param { brokerage: string[] } extraParams
     * @returns Promise<BrokerageAuthorizationTypeObjectResponseType>
     */
    fetchListOfBrokerageAuthorizationTypes(extraParams: {
        brokerage: string[];
    }): Promise<BrokerageAuthorizationTypeObjectResponseType>;
    /**
     * Get a list of stock exchanges and their suffixes
     * @returns Promise<StockExchangeResponseType>
     */
    fetchListOfStockExchanges(): Promise<StockExchangeResponseType>;
    /**
     * Get data relevant to the partner
     * @returns Promise<PartnerDataResponseType>
     */
    partnerData(): Promise<PartnerDataResponseType>;
    /** Portfolio Management **/
    /**
     * List of all portfolio groups.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {RequestOptionsType} [options]
     * @returns Promise<PortfolioGroupResponseType>
     */
    fetchPortfolioGroups({ userId, userSecret }: DefaultQueryParams, options?: RequestOptionsType): Promise<PortfolioGroupResponseType>;
    /**
     * List Portfolio Group positions.
     * @param {DefaultQueryParams} defaultQueryParams
     * @param portfolioGroupId
     * @param {RequestOptionsType} [options]
     * @returns Promise<PortfolioGroupPositionsResponseType>
     */
    fetchPortfolioGroupPrositions({ userId, userSecret }: DefaultQueryParams, portfolioGroupId: string, options?: RequestOptionsType): Promise<PortfolioGroupPositionsResponseType>;
    /** Reporting **/
    /**
     * Get transaction history for a user
     * @param {DefaultQueryParams} defaultQueryParams
     * @param { startDate: string; endDate: string, accounts: string } extraParams
     * @returns Promise<TransactionHistoryResponseType>
     */
    fetchTransactionHistory({ userId, userSecret }: DefaultQueryParams, extraParams?: {
        startDate?: string;
        endDate?: string;
        accounts?: string;
        brokerageAuthorizations?: string[];
    }, options?: RequestOptionsType): Promise<TransactionHistoryResponseType>;
    /**
     * Get performance information for a specific time frame
     * @param {DefaultQueryParams} defaultQueryParams
     * @param {PerformanceInformationQueryParams} extraParams
     * @returns Promise<PerformanceInformationResponseType>
     */
    fetchPerformanceInformation({ userId, userSecret }: DefaultQueryParams, extraParams: PerformanceInformationQueryParams, options?: RequestOptionsType): Promise<PerformanceInformationResponseType>;
}

//# sourceMappingURL=types.d.ts.map
